﻿using System;
using System.Net;
using System.Diagnostics;
using System.Windows.Forms;
using System.Reflection;
using SystemSupportApp.Properties;

namespace SystemSupportApp
{
	class ProcessIcon : IDisposable
	{
       public static void SetNotifyIconText(NotifyIcon ni, string text)
       {
           if (text.Length >= 128) throw new ArgumentOutOfRangeException("Text limited to 127 characters");
           Type t = typeof(NotifyIcon);
           BindingFlags hidden = BindingFlags.NonPublic | BindingFlags.Instance;
           t.GetField("text", hidden).SetValue(ni, text);
           if ((bool)t.GetField("added", hidden).GetValue(ni))
               t.GetMethod("UpdateIcon", hidden).Invoke(ni, new object[] { true });
       }
        
		NotifyIcon ni;
		public ProcessIcon()
		{
			ni = new NotifyIcon();
		}

        public static string GetDetails()
        {
            string UserName = Environment.UserName;
            string hostName = Environment.MachineName;
            string DomainName = Environment.UserDomainName + "\\";
            string DomainServer = System.Environment.GetEnvironmentVariable("logonserver").Remove(0,2);
            string myHost = System.Net.Dns.GetHostName();
            string myIPs = null;
            string GetDetails = null;

            for (int i = 0; i <= System.Net.Dns.GetHostEntry(myHost).AddressList.Length - 1; i++)
            {
                if (System.Net.Dns.GetHostEntry(myHost).AddressList[i].IsIPv6LinkLocal == false)
                {
                    if ((System.Net.Dns.GetHostEntry(myHost).AddressList[i].ToString().IndexOf("169.254")) == 0)
                        myIPs = myIPs + "IP: " + "(NO DHCP)" + Environment.NewLine;
                    else
                        myIPs = myIPs + "IP: " + System.Net.Dns.GetHostEntry(myHost).AddressList[i].ToString() + Environment.NewLine;
                }
            }
            
            if (!hostName.Contains(UserName))
                GetDetails = DomainName + UserName + Environment.NewLine + SystemInformation.ComputerName + Environment.NewLine + DomainServer + Environment.NewLine + myIPs;
            else
                GetDetails = hostName;

        return GetDetails;
        }

		public void Display()
		{
			// Put the icon in the system tray and allow it react to mouse clicks.			
			ni.MouseClick += new MouseEventHandler(ni_MouseClick);
			ni.Icon = Resources.SystemSupportApp;
            SetNotifyIconText(ni,GetDetails());
			ni.Visible = true;
			ni.ContextMenuStrip = new ContextMenus().Create();
		}

		public void Dispose()
		{
			// When the application closes, this will remove the icon from the system tray immediately.
			ni.Dispose();
		}

		public void ni_MouseClick(object sender, MouseEventArgs e)
		{
			// Handle mouse button clicks.
			if (e.Button == MouseButtons.Left)
			{
				// Refresh Display Details.
				Display();
			}
		}
	}
}